@@ -51,8 +51,9 @@
 package com.openexchange.smtp;
 
 import com.openexchange.exception.Category;
+import com.openexchange.exception.LogLevel;
+import com.openexchange.exception.LogLevelAwareOXExceptionCode;
 import com.openexchange.exception.OXException;
-import com.openexchange.exception.OXExceptionCode;
 import com.openexchange.exception.OXExceptionFactory;
 import com.openexchange.mail.MailExceptionCode;
 
@@ -61,7 +62,7 @@ import com.openexchange.mail.MailExceptionCode;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public enum SMTPExceptionCode implements OXExceptionCode {
+public enum SMTPExceptionCode implements LogLevelAwareOXExceptionCode {
 
     /**
      * An I/O error occurred: %1$s
@@ -122,18 +123,21 @@ public enum SMTPExceptionCode implements OXExceptionCode {
     ;
 
     private final String message;
-
     private final int detailNumber;
-
     private final Category category;
-
     private final String prefix;
+    private final LogLevel logLevel;
 
     private SMTPExceptionCode(final String message, final Category category, final int detailNumber) {
+        this(message, category, detailNumber, null);
+    }
+
+    private SMTPExceptionCode(final String message, final Category category, final int detailNumber, final LogLevel logLevel) {
         this.message = message;
         this.detailNumber = detailNumber;
         this.category = category;
         prefix = SMTPProvider.PROTOCOL_SMTP.getName();
+        this.logLevel = logLevel;
     }
 
     private SMTPExceptionCode(final MailExceptionCode code) {
@@ -141,6 +145,7 @@ public enum SMTPExceptionCode implements OXExceptionCode {
         detailNumber = code.getNumber();
         category = code.getCategory();
         prefix = code.getPrefix();
+        logLevel = null;
     }
 
     @Override
@@ -163,6 +168,11 @@ public enum SMTPExceptionCode implements OXExceptionCode {
         return message;
     }
 
+    @Override
+    public LogLevel getLogLevel() {
+        return logLevel;
+    }
+
     @Override
     public boolean equals(final OXException e) {
         return OXExceptionFactory.getInstance().equals(this, e);
@@ -197,4 +207,5 @@ public enum SMTPExceptionCode implements OXExceptionCode {
     public OXException create(final Throwable cause, final Object... args) {
         return OXExceptionFactory.getInstance().create(this, cause, args);
     }
+
 }
